@@ -12,6 +12,11 @@
  *
  * #GooCanvasItemModel defines the interface that models for canvas items must
  * implement, and contains methods for operating on canvas item models.
+ *
+ * <note><para>
+ * 	The Model/View canvas feature may be removed in a future version of
+ * 	GooCanvas.
+ * </para></note>
  */
 #include <config.h>
 #include <math.h>
@@ -37,6 +42,7 @@ enum {
   CHANGED,
 
   CHILD_NOTIFY,
+  ANIMATION_FINISHED,
 
   LAST_SIGNAL
 };
@@ -195,6 +201,23 @@ goo_canvas_item_model_base_init (gpointer g_iface)
 		      G_TYPE_NONE, 1,
 		      G_TYPE_PARAM);
 
+      /**
+       * GooCanvasItemModel::animation-finished
+       * @item: the item model that received the signal.
+       * @stopped: if the animation was explicitly stopped.
+       *
+       * Emitted when the item model animation has finished.
+       */
+      item_model_signals[ANIMATION_FINISHED] =
+	g_signal_new ("animation-finished",
+		      iface_type,
+		      G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (GooCanvasItemModelIface, animation_finished),
+		      NULL, NULL,
+		      g_cclosure_marshal_VOID__BOOLEAN,
+		      G_TYPE_NONE, 1,
+		      G_TYPE_BOOLEAN);
+
 
       g_object_interface_install_property (g_iface,
 					   g_param_spec_object ("parent",
@@ -256,6 +279,13 @@ goo_canvas_item_model_base_init (gpointer g_iface)
 								 FALSE,
 								 G_PARAM_READWRITE));
 
+      g_object_interface_install_property (g_iface,
+					   g_param_spec_string ("tooltip",
+								_("Tooltip"),
+								_("The tooltip to display for the item"),
+								NULL,
+								G_PARAM_READWRITE));
+
       _goo_canvas_style_init ();
 
       initialized = TRUE;
@@ -901,6 +931,8 @@ goo_canvas_item_model_stop_animation (GooCanvasItemModel *model)
 {
   /* This will result in a call to goo_canvas_item_free_animation() above. */
   g_object_set_data (G_OBJECT (model), animation_key, NULL);
+
+  g_signal_emit_by_name (model, "animation-finished", TRUE);
 }
 
 
